#### Nps AAR Analytical Script #####################################################################
# Analytical script for "Assessing the intra-crystalline approach to amino acid 
# geochronology of Neogloboquadrina pachyderma (sinistral)"
# Lucy Wheeler (a*), Kirsty Penkman (a), Hans Petter Sejrup (b)
# (a) Department of Chemistry, University of York, York, YO10 5DD, UK
# (b) Department of Earth Science, University of Bergen, Allgaten 41, N-5007 Bergen, Norway
# 
# * Corresponding author: lw944@york.ac.uk
#
# Required files: 
#   Nps data analysis: 
#      Nps AAR.xlsx (provided as supplimentary information)
#   Age modelling: 
#      rbacon model output is included in Nps AAR.xlsx
#      14C dates from Becker et al. 2018 (https://doi.org/10.1016/j.margeo.2017.09.003)
#      NISP tie points from Brendryen et al. 2011 (https://doi.org/10.1016/j.quascirev.2009.12.004)
#   A/I -> D/L conversion: 
#      Nps AAR.xlsx 
#      Data set from Whitacre et al. 2017 (https://doi.org/10.1016/j.quageo.2016.10.004) 
#

## 1. Workspace set up -----------------------------------------------------------------------------

## 1.1 Working directory and packages --------------------------------------------------------------

## Set working directory - make sure this is the folder containing "Nps AAR.xlsx"
setwd("D:/Lucy Wheeler CV/AAR Data/N pachyderma/R/Supp Info")

## Set save location for graphs - a folder in the working directory
graph_loc <- "Graphs/"

## Required packages
library(tidyverse)  # For data manipulation and plotting
library(Hmisc)      # Additional functions
library(readxl)     # To import from excel spreadsheet
library(gridExtra)  # To arrange graphs in one file
library(plotly)     # For EDA
library(rbacon)     # For age modelling
library(AICcmodavg) # For AICc


## 1.2 Custom functions ----------------------------------------------------------------------------

  ## Function to capitalise first letter of a string
capitalise <- function(string) {       
  substr(string, 1, 1) <- toupper(substr(string, 1, 1))
  string
}

  ## Function to recode and reorder bleach factors - takes format x <- bu_recode(x)
bu_recode <- function(x){
  x$b_u <- x$b_u %>% fct_recode("Bleached" = "b", "Unbleached" = "u") %>%
    fct_relevel("Unbleached", "Bleached")
  return(x)  
  }

  ## Function for quickly tidying up graphs
quick_theme <- function(n, key_pos = "bottom", x_ticks = "y") {
  p <- n +
    theme_light() +                                         ## Changes theme to light
    theme(text = element_text(size = 7),
          panel.grid = element_blank(),                     ## Removes grid
          legend.position = key_pos,                        ## Moves legend to key_pos
          strip.background = element_blank(),               ## Changes facet strip design
          strip.text = element_text(colour = "black"))
  
  if(x_ticks == "n") {
    p <- p + theme(axis.ticks.x = element_blank())          ## Removes x axis ticks
    return(p)
  } else {
    return(p)
  }
}

 ## Function for printing or displaying plots in other functions
choose_print <- function(q,  p_s = "print", name = "Graphs/Untitled.eps", 
                         w = 90, h = 90){        
  if(p_s == "print"){    
    return(q)
  } else if(p_s == "save"){
    ggsave(filename = name, plot = q, device = "eps", 
         width = w, height = h, units = "mm")
  } else {
      return("Please set return to either 'print' or 'save'")
    }
}

## 1.3 Palettes for graphs -------------------------------------------------------------------------

palettes <- list(bl = c("#0a0327", "#0a61be"),
                 five = c("#174099", "#3171B2", "#54ABD8", "#77D1F2", "#BAF1FC"),
                 aa = c("#75041a", "#a50026", "#d73027", "#f46d43", "#fdae61", "#fee090", 
                        "#ffffbf", "#e0f3f8", "#aad0e5", "#abd9e9", "#74add1", "#4575b4", 
                        "#313695", "#2a167a", "#989898", "#f46d43"))

  ## Palette names
names(palettes$bl) <- c("Unbleached", "Bleached")
names(palettes$aa) <- c("Asx", "Glx", "Ser", "Thr", "His", "Gly", "Arg", "Ala", "Tyr", 
                       "Val", "Met", "Phe", "Leu", "Ile", "Other", "Ser + Thr")


## 1.4 Import and rearrange AAR data ---------------------------------------------------------------

## USE IMPORT FROM MISC BITS FOR NOW ##

 ## Import RP-HPLC data 
rp_nps <- (function(){
  
    ## Import RP data from Nps AAR spreadsheet and calculate [Ser]/[Ala] and % Gly
    ## It may be necessary to rename the file
  aar_wide <- read_excel("Nps AAR.xlsx", sheet = "RP", range = "A1:AE217") %>%
    mutate(ser_ala = as.numeric(ser_c) / as.numeric(ala_c),
           pc_gly = (as.numeric(gly_c) / as.numeric(total_conc)) * 100)

    ## Make DL table - select DL variables and tidy
  aar_dl <- aar_wide %>%                                                             
    select(-c(asx_c:ile_c)) %>%                                                            
    gather(amino_acid, dl, -c(sample_name:total_conc, pc_gly, ser_ala))                        
  
    ## Make conc table - select conc variables and tidy
  aar_conc <- aar_wide %>%                                                                
    select(-c(asx:ile)) %>%                                                                
    gather(amino_acid, conc, -c(sample_name:total_conc, pc_gly, ser_ala)) %>%
    mutate(amino_acid = gsub(pattern = "_c", replacement = "", amino_acid))
    
    ## Join conc and DL tables
  aar <- aar_conc %>%                                                                     
    left_join(aar_dl, by = NULL)    

    ## Coerce forams, concentration and D/L variables into numeric,
    ## make depth correction for MD-992288 samples 
    ## and convert concentrations from pmol/foram to nmol/foram
  aar <- aar %>% 
          # Recode b and u to Bleached and Unbleached
    bu_recode() %>%        
    mutate(forams = as.numeric(forams),
           total_conc = (as.numeric(total_conc) / 1000),
           conc = (as.numeric(conc) / 1000),
           dl = as.numeric(dl),
              # Make depth correction to samples from below 2300 cm
           depth = ifelse(depth >= 2300, depth - 33.5, depth))
           
    ## Convert select column names into factors and enforce their order
  aar$amino_acid <- aar$amino_acid %>% 
    capitalise() %>%
    factor() %>% 
    fct_inorder()                         

  return(aar)
                                                                          
         })()

  ## Import IEC data 
iex_nps <- (function(){
  
    ## Import IEC data from Nps AAR spreadsheet and calculate [Ser]/[Ala] and % Gly
    ## It may be necessary to rename the file
  aar_wide <- read_excel("Nps AAR.xlsx", sheet = "IEC", range = "A1:Q142") %>%
    mutate(ser_ala = as.numeric(ser) / as.numeric(ala),
           pc_gly = (as.numeric(gly) / as.numeric(total_conc)) * 100)
    
    ## Gather concentrations, coerce concentration and A/I variables into numeric,
    ## make depth correction for MD-992288 samples, add a bleach time in days (b_t_d) var
    ## and convert concentrations from pmol/foram to nmol/foram
  aar <- aar_wide %>% 
    gather(amino_acid, conc, -c(sample_name:total_conc, a_i, ser_ala, pc_gly)) %>%
    mutate(conc = as.numeric(conc),
           a_i = as.numeric(a_i),
           b_t_d = fct_inorder(as.factor((bleach_time / 24))),
           depth = ifelse(depth >= 2300, depth - 33.5, depth),
           conc = conc / 1000,
           total_conc = total_conc / 1000) %>% 
    bu_recode() %>%
    group_by(depth, b_u, amino_acid, b_t_d) 
  
    ## Combine Ser and Thr
  aar$amino_acid <- aar$amino_acid %>%
    capitalise() %>%
    fct_other(drop = c("Ser", "Thr"), other_level = "Ser + Thr") %>% 
    fct_inorder() %>%
    fct_relevel("Asx", "Glx", "Ser + Thr", "Gly") 
  aar <- aar %>% 
    group_by(sample_name, b_u, bleach_time, forams, total_conc,
             a_i, depth, amino_acid, b_t_d, ser_ala, pc_gly) %>%
    summarise_at("conc", sum, na.rm = TRUE) 
  
  return(aar)
})()



## 2. Outliers -------------------------------------------------------------------------------------

## 2.1 Ser, Gly and Thr % Contributions ------------------------------------------------------------
## Screening criterion: >50% Gly

  ## Filter RP samples for just Ser, Gly and Thr, and calculate % of each AA
rp_nps_sgt <- rp_nps %>% ungroup() %>%
  select(sample_name, depth, b_u, total_conc, amino_acid, conc) %>%
  filter(amino_acid == "Ser" | amino_acid == "Gly" | amino_acid == "Thr") %>%
  mutate(pc_conc = (conc / total_conc) * 100)

  ## Plot depth against percent contribution
p <- ggplot(rp_nps_sgt, aes(x = depth, y = pc_conc, colour = b_u, z = sample_name)) +   
  geom_point()

  ## Facet by amino acid and label samples with Gly > 50%
p2 <- quick_theme(p) + facet_wrap(amino_acid ~ ., scales = "free") +
  scale_colour_manual(values = palettes$bl) +
  labs(x = "Depth, m", y = "% Contribution", colour = NULL) +
  geom_text(data = filter(rp_nps_sgt, amino_acid == "Gly", pc_conc > 50), 
            aes(label = sample_name), na.rm = TRUE, nudge_x = 270, size = 2)

  ## View interactive plot
ggplotly(p2)

#### Samples with >50% Gly:
#### 0639uH, 0637bH, 0640bH, 0640uH (1 analytical rep only - chromatography issues?) 
#### No clear trends/outliers for Ser and Thr

# IEC - Gly and Ser+Thr against depth, Thr+Ser> 21% labelled

  ## Calculate % conc for each amino acid
iex_nps_sgt <- iex_nps %>% 
  group_by(sample_name, depth, b_u, amino_acid, total_conc) %>%
  mutate(pc_conc = (conc / total_conc) * 100) %>%
  filter(amino_acid == "Gly" | amino_acid == "Ser + Thr")

  ## Plot depth against percent contribution
p <- ggplot(iex_nps_sgt, aes(x = depth, y = pc_conc, colour = b_u, z = sample_name)) +
  geom_point()

  ## Facet by amino acid and label samples with Thr+Ser > 21%
p2 <- quick_theme(p) + facet_wrap(amino_acid ~ ., scales = "free") +
  scale_colour_manual(values = palettes$bl) +
  labs(x = "Depth, m", y = "% Contribution", colour = NULL) +
  geom_text(data = filter(iex_nps_sgt, amino_acid == "Thr + Ser", pc_conc > 21),
            aes(label = sample_name), na.rm = TRUE, nudge_x = 270, size = 2)

  ## View interactive plot
ggplotly(p2)

#### Some samples have very low Gly or Ser+Thr concentrations - 
#### likely to be chromatographic issues?
#### No samples > 50% Gly

# ## 2.2. [Ser]/[Ala] --------------------------------------------------------------------------------
# ## Screening criterion: [Ser]/[Ala] > 1.5 (RP only)
# 
#   ## Filter out duplicate amino acids and plot [Ser]/[Ala] against depth
# p <- ggplot(filter(rp_nps, amino_acid == "Gly"),
#             aes(x = depth, y = ser_ala, z = sample_name)) +
#   geom_point()
# 
#   ## Facet by bleached/unbleached and label samples with [Ser]/[Ala] > 1.5
# p2 <- quick_theme(p) + facet_wrap(b_u ~ ., scales = "fixed") +
#   labs(x = "Depth, cm", y = "[Ser]/[Ala]") +
#   geom_text(data = filter(rp_nps, amino_acid == "Gly", ser_ala > 1.5), 
#             aes(label = sample_name), na.rm = TRUE, size = 2, nudge_x = 270)
# 
#   ## View interactive plot
# ggplotly(p2, tooltip = c("x", "y", "z"))
# 
# ## Samples with [Ser]/[Ala] > 1.5
# ## 0584uH (one replicate is >1.5; other is 1.44 - remove both), 0579uH (both replicates)


## 2.3 D/L -----------------------------------------------------------------------------------------
## Screening criterion: Asx, Glx or Ala D/L (RP) or Ile A/I falling off general trend

dl_outlier_plot <- function(data, bu = "Bleached", yvar = "dl"){
    ## Filter b or u and select key AA's
  df <- filter(data, b_u == bu,
               amino_acid == "Asx" | amino_acid == "Glx" | amino_acid == "Ala")

    ## Plot depth against D/L 
  p <- ggplot(df, aes_string(x = "depth", y = yvar, z = "sample_name")) + 
    geom_point() 
  
    ## Facet by amino acid and add labels
  p2 <- quick_theme(p) + 
    facet_wrap(amino_acid ~ ., scales = "free") +
    labs(x = "Depth, cm", y = "D/L")

  return(p2)
}

  ## View interactive plots for RP data
ggplotly(dl_outlier_plot(rp_nps, "Bleached", "dl"), tooltip = c("x", "y", "z"))
ggplotly(dl_outlier_plot(rp_nps, "Unbleached", "dl"), tooltip = c("x", "y", "z"))

#### RP outliers: 
#### 0983bH - below trend for Asx, Glx and Ala (both replicates)
#### 0985bH - above trend for Glx and Ala (both replicates)
#### 0579bH - below trend for Asx and Glx (both replicates)
#### 0591uH - below trend for Asx only (both replicates)
#### 0982uH - below trend for Asx and Glx (both repliates)
#### 0579uH - below trend for Asx, Glx and Ala (both replicates)

 ## View plot for IEC data (ignore faceting)
ggplotly(dl_outlier_plot(iex_nps, "Bleached", "a_i"), tooltip = c("x", "y", "z"))
ggplotly(dl_outlier_plot(iex_nps, "Unbleached", "a_i"), tooltip = c("x", "y", "z"))

#### IEC outliers:
#### Bleached:
#### BAL3834B - extremely high A/I
#### BAL3812B - below trend for A/I
#### BAL3798B - below trend for A/I
#### BAL3806B - below trend for A/I
#### Unbleached:
#### BAL3707C - above trend for A/I
#### BAL3809C - extremely high A/I 
#### BAL3708B - below trend for A/I
#### BAL3707A - below trend for A/I
#### BAL3759B - below trend for A/I

## 2.4 Remove outliers and average -----------------------------------------------------------------

 ## Remove outliers from RP dataset
rp_nps2 <- rp_nps %>% filter(pc_gly <= 50,              ## Replicates where %Gly > 50
      sample_name != "0983bH*", sample_name != "0985bH*", ## Samples where D/L falls off
      sample_name != "0579bH", sample_name != "0591uH",   ## the trend
      sample_name != "0982uH*", sample_name != "0579uH")

 ## Average replicates 
rp_nps_av <- rp_nps2 %>%
  group_by(sample_name, b_u, amino_acid, depth) %>%
  summarise_at(c("conc", "dl", "total_conc"), mean, na.rm = TRUE)

 ## Remove outliers from RP dataset 
iex_nps2 <- iex_nps %>% 
      filter(sample_name != "BAL3834B", sample_name != "BAL3812B", 
             sample_name != "BAL3798B", sample_name != "BAL3806B",
             sample_name != "BAL3707C", sample_name != "BAL3809C", 
             sample_name != "BAL3708B", sample_name != "BAL3707A", 
             sample_name != "BAL3759B",)

## 3. Extended bleaching experiments ---------------------------------------------------------------

## 3.1 Effect of bleaching on concentration and A/I ------------------------------------------------


  ## Create subset of data with just extended bleaching experiments (250 cm, 500 cm, 
  ## 1450 cm)
iex_bleach <- (function(){
  
    ## Filter only depths used for extended bleach experiments
  iex_bleach <- iex_nps2 %>%
    ungroup() %>% 
    filter(depth == 250 | depth == 500 | depth == 1450, amino_acid != "Met") %>%
    arrange(bleach_time) %>%
    separate(sample_name, into = c("lab_id", "rep_id"), sep = -1, convert = TRUE) %>%
    mutate(rep_id = fct_inorder(as.factor(rep_id)),
           bleach_time = fct_inorder(as.factor(bleach_time)),
           b_t_d = fct_inorder(as.factor(b_t_d)),
           pc_conc = (conc / total_conc) * 100)
  
    ## Recode depth as factor with units
  iex_bleach$depth <- iex_bleach$depth %>%    
    as.factor() %>% fct_recode("a) 250 cm, 18.0 ka" = "250", "b) 500 cm, 19.7 ka" = "500", 
                "c) 1450 cm, 55.6 ka" = "1450")
  
    ## Create percentage concentration column
  iex_bleach <- iex_bleach %>% mutate(pc_conc = (conc / total_conc) * 100)

  return(iex_bleach)
})()

  ## Set up a basic graph for plotting variables against bleaching time for each depth
plot_bleachtime <- function(x, yvar, ylab, stat = "point", result = "print"){            
  
    ## Set up bleach time bar chart against depth
  p <- ggplot(x, aes_string(x= "bleach_time", y = yvar)) +   
    geom_bar(stat = "summary", fun.y = "mean", 
             na.rm = TRUE, fill = palettes$five[3])
  
    ## Add extra geoms according to the stat argument
  if(stat == "point"){            # Add point for every replicate
    p2 <- p + 
      geom_point(aes(x = bleach_time), colour = "black", show.legend = FALSE, size = 1)
    
  } else if(stat == "error"){     # Add error bars
    p2 <- p +
      stat_summary(fun.data = mean_sdl, fun.args = list(mult = 1), geom = "errorbar", 
          width = 0.3, position = position_dodge(width = 1)) 
  }
  
    ## Apply quick theme, facet by depth and add labels
  p3 <- quick_theme(p2, key_pos = "none") +             
    facet_grid(. ~ depth) +               
    labs(fill = "Bleach time,\nhours", y = ylab, x = "Bleach time, hours") + 
    scale_y_continuous(expand = expand_scale(mult = c(0, 0.05))) +
    theme(axis.text.x = element_text(angle = 90, hjust = 1))
  
    ## Choose whether to print or save according to result
  choose_print(q = p3, p_s = result,      
               name = paste0(graph_loc, "IEC ", yvar, " vs bleach time ", stat, ".eps"),
               w = 90, h = 60)
}

  ## Plot total concentration and A/I against bleaching time at the three depths
plot_bleachtime(iex_bleach, "total_conc",
   ylab = "Total hydrolysable amino acid\nconcentration, nmol / foram",                   
   stat = "point", result = "save") 

plot_bleachtime(iex_bleach, "total_conc",
   ylab = "Total hydrolysable amino acid\nconcentration, nmol / foram", 
   stat = "error", result = "save") 

plot_bleachtime(iex_bleach, "a_i", 
   ylab = "A/I", stat = "point", result = "save")    

plot_bleachtime(iex_bleach, "a_i", 
   ylab = "A/I", stat = "error", result = "save")


 ## Calculate % change in concentration from unbleached to bleached for each depth

bleach_change <- iex_bleach %>% 
  ungroup() %>%
  group_by(bleach_time, depth) %>%
  summarise(av_conc = mean(total_conc)) %>%
  ungroup() %>%
  mutate(bleach_time = paste0("c", bleach_time)) %>%
  spread(bleach_time, av_conc) %>%
  mutate(pc24 = (c24 / c0)*100,
         pc48 = (c48 / c0)*100,
         pc120 = (c120 / c0)*100,
         pc336 = (c336 / c0)*100,
         pc360 = (c360 / c0)*100)

# depth                 24    48    120   336   360
#	a) 250 cm, 18.0 ka	  95.9	40.1	28.0	NA	  18.4
#	b) 500 cm, 19.7 ka		134.0	94.3	175.9	NA	  61.7
#	c) 1450 cm, 55.6 ka		21.4	29.1	22.5	89.5	NA


## Concentration change between bleached and unbleached samples at all depths 
  
    ## Set up bleach time bar chart against depth
  p <- ggplot(filter(iex_nps2, b_t_d == "0" | b_t_d == "2"), 
              aes(x = depth, y = total_conc, colour = b_u, shape = b_u)) +   
         geom_point(size = 1)
    
     ## Apply quick theme, facet by depth and add labels
  p2 <- quick_theme(p, key_pos = "bottom") +                 
    labs(colour = NULL, shape = NULL, 
         y = "Total hydrolysable amino acid\nconcentration, nmol / foram", x = "Depth, cm") +
     scale_colour_manual(values = palettes$bl) +
     scale_shape_manual(values = c(17, 16)) +     
     theme(legend.box.spacing = unit(0, "mm"),
           legend.margin = margin(0,0,0,0, unit = "mm"))

    ## Save to file
 ggsave(filename = "Graphs/THAA conc all depths.eps", plot = p2, device = "eps", 
         width = 90, height = 60, units = "mm")
  
  

## 3.2 Effect of bleaching on compositon -----------------------------------------------------------

  ## Area graph of amino acid composition for bleach times
area_sock <- function(x, result = "print"){      
  
    ## Convert bleach time to numeric
  x$bleach_time <- as.numeric(as.character(x$bleach_time))
    ## Remove instances of 0 
  x$pc_conc[is.na(x$pc_conc)] <- 0
  
  x$depth <- x$depth %>%    
    fct_recode("a) 250 cm\n18.0 ka" = "a) 250 cm, 18.0 ka", 
               "b) 500 cm\n19.7 ka" = "b) 500 cm, 19.7 ka", 
               "c) 1450 cm\n55.6 ka" = "c) 1450 cm, 55.6 ka")
  
  

    ## Plot bleach time against amino acid compositon
  p <- ggplot(x, aes(x = bleach_time, y = pc_conc, fill = amino_acid)) +   
    geom_area(stat = "summary", position = position_fill(),
              fun.y = "mean", na.rm = TRUE, colour = "white") 
  
    ## Facet against depth, wrangle with axes and add labels
  p2 <- quick_theme(p, key_pos = "right") +          
    facet_wrap( ~ depth, ncol = 3) +
    labs(fill = "Amino acid", x = "Bleach time, hours", 
         y = "Percentage contribution") +
    scale_fill_manual(values = palettes$aa) +
    scale_x_continuous(breaks = c(0, 180, 360), expand = c(0, 0)) +
    scale_y_continuous(expand = c(0,0), labels = scales::percent_format()) +
    theme(panel.border = element_blank(), panel.spacing = unit(3, "mm"),
          legend.margin = margin(0,0,0,0, unit = "mm")) 
  
    ## Choose whether to print or save according to result
  choose_print(q = p2, p_s = result,        
               name = paste0(graph_loc, "IEX bleach comp.eps"),
               w = 90, h = 60)
  }

  ## Save to file
area_sock(iex_bleach, result = "save")

  ## Average contribution from each amino acid
iex_bleach %>% 
  ungroup() %>%
  group_by(amino_acid) %>%
  summarise(mean_pc = mean(pc_conc, na.rm = TRUE),
            sd_pc = sd(pc_conc, na.rm = TRUE)) %>%
  mutate(cov_pc = (sd_pc / mean_pc) * 100) %>%
  arrange(desc(mean_pc))


## 3.3 Composition change on bleaching for all depths ----------------------------------------------

depth_comp <- function(x, maxdepth = 2985, result = "print", area_stat = "mean"){

    ## Calculate percent concentration
  y <- x %>% 
    mutate(pc_conc = (conc / total_conc) * 100) 
  y$pc_conc[is.na(y$pc_conc)] <- 0 

    ## Plot composition against depth
  p <- ggplot(filter(y, depth <= maxdepth), 
        aes(x = depth, y = pc_conc, fill = amino_acid)) +
    geom_area(stat = "summary", position = position_fill(),
        fun.y = area_stat, na.rm = TRUE, colour = "white")

    ## Facet by bleached/unbleached, wrangle axes and add labels
  p2 <- quick_theme(p, key_pos = "right") + facet_grid(. ~ b_u) + 
    scale_fill_manual(values = palettes$aa) +
    labs(x = "Depth, cm", y = "Percentage contribution", fill = "Amino acid") +
    coord_cartesian(xlim = c(0, maxdepth)) +
    scale_x_continuous(breaks = c(10, 1000, 2000, maxdepth), expand = c(0, 0)) +
    scale_y_continuous(expand = c(0,0), labels = scales::percent_format()) +
    theme(panel.border = element_blank(), panel.spacing = unit(3, "mm"), 
          axis.text.x = element_text(angle = 45, vjust = 1, hjust = 1))

    ## Choose whether to print or save according to result
  choose_print(q = p2, p_s = result,        
               name = paste0(graph_loc, deparse(substitute(x)), 
                             " bleach depth 0-", maxdepth,".eps"),
               w = 90, h = 60)

}

  ## Remove Met (no response) and reorder amino acids for IEC data
iex_nps_comp <- iex_nps2 %>% filter(amino_acid != "Met", b_t_d == 0 | b_t_d == 2) 
iex_nps_comp$amino_acid <- iex_nps_comp$amino_acid %>% 
  fct_relevel("Asx", "Glx", "Ser + Thr", "Gly", "Ala", "Val", "Leu", "Ile") 

  ## Depth plot of composition of bleached/unbleached samples (IEC)
depth_comp(iex_nps_comp, maxdepth = 3000, result = "save", area_stat = "mean")

 ## Combine Ser and Thr, and small amino acids into other level for RP data
rp_nps_comp <- rp_nps_av
rp_nps_comp$amino_acid <- rp_nps_comp$amino_acid %>%
      fct_other(drop = c("Ser", "Thr"), other_level = "Ser + Thr") %>%
      fct_other(drop = c("His", "Arg", "Met", "Tyr", "Phe"), other_level = "Other") %>% 
      fct_relevel("Asx", "Glx", "Ser + Thr", "Gly", "Ala", "Val", "Leu", "Ile", "Other") 
  
 ## Depth plot of composition of bleached/unbleached samples (RP) 
depth_comp(rp_nps_comp, maxdepth = 2951.5, result = "save", area_stat = "sum")

 ## Average contribution of "other" amino acids to THAA pool
rp_nps_comp %>%
  mutate(pc_conc = (conc / total_conc) * 100) %>%
  filter(amino_acid == "Other") %>%
  group_by(sample_name, b_u) %>%
  summarise(pc_conc = sum(pc_conc, na.rm = TRUE)) %>%
  ungroup() %>%
 # group_by(b_u) %>%
  summarise(mean_pc = mean(pc_conc, na.rm = TRUE),
            sd_pc = sd(pc_conc, na.rm = TRUE))


## 4. Age trends -----------------------------------------------------------------------------------

## 4.1 Age model -----------------------------------------------------------------------------------
#### See rbacon manual for how to set up and run age model (requires raw ages in rbacon format)

#   ## Run age depth model
# Bacon(core = "MD99-2289", thick = 25, acc.mean = 50, depths.file = TRUE)  
# 
#   ## Load model information without running
# Bacon("MD99-2289", run = FALSE)                                                          
# 
#   ## Plot age depth model
# agedepth(rotate.axes = TRUE, title = "", yr.lab = "Years", d.lab = "Depth, cm",  
#          mirror = TRUE, mn.col = "darkblue", mn.lty = 1, dark = 0.5)
# 
# 
#   ## Get list of depths for which D/L data was collected
# dldepths <- distinct(rbind(rp_nps2["depth"], iex_nps2["depth"])) %>%
#   filter(depth > 99, depth < 1851) %>%
#   arrange(depth)
#
# 
#   ## Calculate age ranges for every depth with D/L data 
#   ## (only works when model has been run in session)
# agedepth <- Bacon.hist(dldepths$depth, set = get("info"), calc.range = TRUE)
# 
# 
#   ## Attach age and D/L data
# 
#   ## Wrangle with agedepth dataframe
# agedepth <- data.frame(agedepth)
# names(agedepth) <- c("age_min", "age_max", "age_median", "age_mean")
# agedepth <- agedepth %>% 
#       mutate(depth = dldepths, age_min = age_min / 1000, age_max = age_max / 1000,
#       age_median = age_median / 1000, age_mean = age_mean / 1000)
#
#  ## Save agedepth data frame to skip rerunning age model
# write.csv(agedepth, file = "Bacon_runs/MD99-2289 b/agedepth.csv")  

  ## Load agedepth data frame from Nps AAR file:
age_wrangle <- function(x){
  
    ## Load age model output (see Nps AAR file)
  agedepth <- read_excel("Nps AAR.xlsx", sheet = "Age model", range = "A1:E48")
  
    ## For IEC data - take out extended bleaching experiment data and remove columns
  if("bleach_time" %in% colnames(x)){
    x <- x %>% ungroup() %>% 
      filter(bleach_time <= 48)
  }
  
    ## Collect DL data for range with chronological control  
    ## and make percent concentration column
  y <- x %>% filter(depth > 99, depth < 1851) %>%
    mutate(pc_conc = (conc / total_conc) * 100)
  
    ## Join DL to age depth model
  z <- left_join(y, agedepth, by = "depth")                                      
  
  return(z)
}

iex_age <- age_wrangle(iex_nps2)
rp_age <- age_wrangle(rp_nps2)

## 4.2 A/I vs depth and age in same plot -----------------------------------------------------------

  ## Collect AI values for depths 
iex_nps3 <- iex_nps2 %>% ungroup() %>%
  select(b_u, a_i, depth, amino_acid) %>% 
  filter(amino_acid == "Asx") %>% 
  mutate(age_depth = "depth", x_var = depth, x_min = depth, x_max = depth) %>%
  select(-c(depth, amino_acid))

  ## Collect AI values for ages
iex_age2 <- iex_age %>% filter(amino_acid == "Asx") %>%
  select(b_u, a_i, age_median, age_min, age_max) %>%
  rename(x_var = age_median, x_min = age_min, x_max = age_max) %>%
  mutate(age_depth = "age") %>%
  select(b_u, a_i, age_depth, x_var, x_min, x_max)

  ## Combine two data frames
iex_age3 <- rbind(iex_age2, iex_nps3)

  ## Reorder age and depth for plot
iex_age3$age_depth <- iex_age3$age_depth %>%
  as.factor() %>%
  fct_relevel("depth", "age")

  ## Tidy up
rm(iex_nps3, iex_age2)

  ## Set up plot with point and smoothed line for clarity
p <- ggplot(iex_age3, aes(x = x_var, y = a_i, colour = b_u, shape = b_u)) +
        geom_smooth(se = FALSE, span = 2, size = 0.5) +
        geom_point(size = 0.5) +
        geom_errorbarh(aes(xmax = x_max, xmin = x_min, y = a_i, colour = b_u),
                       size = 0.3)

  ## Faceting by age/depth and formatting
p2 <- quick_theme(p) +
     facet_wrap(age_depth ~ ., ncol = 2, scales = "free_x", strip.position = "bottom",
          labeller = labeller(age_depth = c("depth" = "a) Depth, cm",
                                            "age" = "b) Age, ka"))) +
     scale_colour_manual(values = palettes$bl) +
     scale_shape_manual(values = c(17, 16)) + 
     theme(strip.placement = "outside",
           legend.box.spacing = unit(0, "mm"),
           legend.margin = margin(0,0,0,0, unit = "mm")) +
     labs(x = NULL, y = "A/I", colour = NULL, shape = NULL)
p2

  ## Save graph to file
ggsave(filename = paste0(graph_loc, "IEX AI v age and depth with errors.eps"),                
       plot = p2, width = 90, height = 70, device = "eps", units = "mm")

## 4.3 D/L vs depth and age in same plot -----------------------------------------------------------

  ## Collect DL values Asx, Glx, Ser and Ala for depths 
rp_nps3 <- rp_nps_av %>% ungroup() %>%
  filter(amino_acid == "Asx" | amino_acid == "Glx" | 
           amino_acid == "Ser" | amino_acid == "Ala") %>%
  select(b_u, dl, depth, amino_acid) %>% 
  mutate(age_depth = "depth", x_var = depth, x_min = depth, x_max = depth) %>%
  select(-depth)

  ## Collect DL values Asx, Glx, Ser and Ala values for ages
rp_age2 <- rp_age %>% 
  select(b_u, amino_acid, dl, age_median, age_min, age_max) %>%
  filter(amino_acid == "Asx" | amino_acid == "Glx" | 
           amino_acid == "Ser" | amino_acid == "Ala") %>%
  rename(x_var = age_median, x_min = age_min, x_max = age_max) %>%
  mutate(age_depth = "age") %>%
  select(b_u, dl, amino_acid, age_depth, x_var, x_min, x_max)

  ## Combine two data frames
rp_age3 <- rbind(rp_age2, rp_nps3)

  ## Reorder age and depth for plot
rp_age3$age_depth <- rp_age3$age_depth %>%
  as.factor() %>%
  fct_relevel("depth", "age")

  ## Tidy up
rm(rp_nps3, rp_age2)

  ## Set up plot of RP DLs against age and depth
rp_ageplot <- function(x, file_suffix = "all", result = "print"){
  
  ## Set up plot with point and smoothed line for clarity
p <- ggplot(x, aes(x = x_var, y = dl, colour = b_u, shape = b_u)) +
        geom_smooth(se = FALSE, span = 1.5, size = 0.5) +
        geom_point(size = 0.5) +
        geom_errorbarh(aes(xmax = x_max, xmin = x_min, y = dl, colour = b_u), 
                       size = 0.3)

  ## Faceting by age/depth and amino acid, and formatting
p2 <- quick_theme(p) +
     facet_grid(amino_acid ~ age_depth, scales = "free", switch = "both",
          labeller = labeller(age_depth = c("depth" = "a) Depth, cm",
                                            "age" = "b) Age, ka"),
                              amino_acid = c("Asx" = "i) Asx D/L", "Ser" = "iii) Ser D/L", 
                                        "Glx" = "ii) Glx D/L", "Ala" = "iv) Ala D/L"))) +
     scale_colour_manual(values = palettes$bl) +
     scale_shape_manual(values = c(17, 16)) +
     theme(strip.placement = "outside",
           legend.box.spacing = unit(0, "cm"),
           legend.margin = margin(0,0,0,0, unit = "mm")) +
     labs(x = NULL, y = NULL, colour = NULL, shape = NULL)

    ## Choose whether to print or save according to result
  choose_print(q = p2, p_s = result,        
               name = paste0(graph_loc, "RP DL v age and depth faceted with errors - ", 
                             file_suffix, ".eps"),
               w = 90, h = 140)

}

  ## Plot full range of RP DL data
rp_ageplot(rp_age3, result = "save")

  ## Plot <60 ka RP DL only
rp_ageplot(filter(rp_age3, x_var <= 60 | x_var >= 120, x_var <= 1500),
           file_suffix = "60ka", result = "save")



## 4.4 D/L covariance (RP only) --------------------------------------------------------------------

## Set up graph to plot two amino acids (aa1 and aa2) against each other 
dl_aa_covariance <- function(aa1, aa2, point = 0.5, result = "print"){
  
  x <- rp_nps2 %>%
   filter(amino_acid == "Asx" | amino_acid == "Glx") %>%
   select(sample_name, total_conc, b_u, amino_acid, dl) %>%
   spread(amino_acid, dl)
  
## Set up plot of aa1 against aa2  
  p <- ggplot(x, aes_string(aa1, aa2)) +  
     ## Change se to TRUE to see 95% confidence interval
    geom_smooth(span = 1, se =  FALSE, colour = "black", alpha = 0.5, size = point) +                    
    geom_point(size = point, na.rm = TRUE, colour = palettes$bl[["Bleached"]]) 
  
      ## Formatting and labels
  p2 <- quick_theme(p, key_pos = "bottom") +  facet_grid(. ~ b_u) +                     
     labs(x = paste(aa1, "D/L"), y = paste(aa2, "D/L")) 
  
    ## Choose whether to print or save

  choose_print(q = p2, p_s = result,                                                      
               name = paste0(graph_loc, "RP DL Covariance - ", 
                             aa1, ", ", aa2, ".eps"),  
               w = 90, h = 60)
}


  ## For paper:
dl_aa_covariance("Asx", "Glx", 0.5, "save")

  ## For graphical abstract:
p <- dl_aa_covariance("Asx", "Glx", 1, "print") +
  theme(axis.text = element_blank(), 
        axis.ticks = element_blank(),
        strip.text.x = element_blank()) +
  labs(x = "Aspartic acid D/L", y = "Glutamic acid D/L")

ggsave(filename = paste0(graph_loc, "Asx Glx Covariance for abstract.eps"), 
       plot = p, device = "eps", width = 80, height = 50, units = "mm")

 
## 5. A/I to D/L conversion ------------------------------------------------------------------------
#### See Whitacre et al. 2017 (https://doi.org/10.1016/j.quageo.2016.10.004) for data
#### set used in pooled regressions. Many thanks to Matthew Kosnik for help with this
#### code!

## 5.1 Data Wrangling ------------------------------------------------------------------------------

  ## Calculate log2 of RP DLs:
rp_nps_log <- rp_nps2 %>%
    filter(dl <= 1.4) %>%      ## Take out 1 rep with Val D/L = 1.45 (1077bH) 
    mutate(logdl = log2(dl)) %>%    
    ungroup() %>%
    group_by(b_u, amino_acid, depth) 

  ## Calculate mean and standard deviation of logged RP DLs, spread and join
rp_nps_log_mean <- rp_nps_log %>%
    summarise(logdl_mean = mean(logdl, na.rm = TRUE)) %>%
    spread(amino_acid, logdl_mean) %>% 
    select(b_u, depth, Asx, Glx, Ala, Val, Ile)

rp_nps_log_sd <- rp_nps_log %>%
  summarise(logdl_sd = sd(logdl, na.rm = TRUE)) %>%
  spread(amino_acid, logdl_sd) %>% 
  select(b_u, depth, Asx, Glx, Ala, Val, Ile)

rp_nps_log <- full_join(rp_nps_log_mean, rp_nps_log_sd, by = c("b_u", "depth"), 
                        suffix = c("_mean", "_sd"))

  ## Tidy up
rm(rp_nps_log_mean, rp_nps_log_sd)

  ## Calculate log2 of IEx AI, and mean and standard deviation
iex_nps_log <- iex_nps2 %>%
  mutate(logai = log2(a_i)) %>%                                                      
  ungroup() %>%
  filter(bleach_time == 0 | bleach_time == "48") %>%
  group_by(b_u, depth) %>%
  summarise(logai_mean = mean(logai, na.rm = TRUE),                                       
            logai_sd = sd(logai, na.rm = TRUE))

  ## Combine RP and IEx data - including only "pairs" of same depth and bleach treatment:
nps_log_bu <- inner_join(rp_nps_log, iex_nps_log, by = c("depth", "b_u"))

 ## Remove instances where log2(A/I) is NA 
nps_log_bu <- nps_log_bu %>% filter(!is.na(logai_mean))

## 5.2 Run linear models of log2 transformed data and produce summary statistics -------------------

 ## List of amino acids for which to run models
modlist <- list("Asx_mean", "Glx_mean", "Ala_mean", "Val_mean", "Ile_mean")
modlist2 <- list("Asx", "Glx", "Ala", "Val", "Ile")

  ## Create models
nps_models <- lapply(modlist, function(x){
    lm(reformulate("logai_mean", x), data = nps_log_bu)
                })
names(nps_models) <- gsub("_mean", "", modlist) ## Rename models with amino acids


  ## Collect summary statistics for each model
res <- do.call(rbind,            ## rbind combines the lapply list into a matrix
    lapply(nps_models, function(x) { ## Collect these bits of information from each model
      coefs <- coef(summary(x))
      c( slope = coefs["logai_mean", "Estimate"],          ## Collect slope
         slope_se = coefs["logai_mean","Std. Error"],      ## Collect +/- 1SD of slope
         intercept = coefs["(Intercept)", "Estimate"],     ## Collect intercept
         intercept_se = coefs["(Intercept)","Std. Error"], ## Collect +/1 1SD of intercept
         r2 = round(summary(x)$adj.r.squared, 4),          ## Collect R^2
         aic = round(AICc(x),2),                           ## Calculate AICc  
         k = AICc(x, return.K=TRUE)                        ## Calculate k
      )
    })
  )

res <- data.frame(res) %>%                              ## Convert to data frame
  mutate(amino_acid = gsub("_mean", "", modlist),       ## Add column for amino acids   
         n = unlist(lapply(modlist, function(x){        ## Add in n for each amino acid
                               sum(!is.na(nps_log_bu[[x]]))
                                      })))


## Prediction uncertainties for each model

   ##  Generate "fake" data with which to generate prediction intervals
predData <- data.frame(logai_mean = round(seq(
  floor(min(nps_log_bu[,'logai_mean'], na.rm = TRUE) * 10) / 10 , 
  ceiling(max(nps_log_bu[,'logai_mean'], na.rm = TRUE) * 10) / 10, 
  by = 0.1), 1))      

  ## Function to calculate preduction quantiles for each model based on predData
calc_quants <- function(aa, mod = nps_models, data = predData){

    ## Quantiles (interquantile, 1 SD, 2 SD)
  qSD <- c(0.5, 0.6827, 0.9973) 
  
    ## Predict results for new data
  predictions <- predict(mod[[aa]], newdata = data, interval = "prediction")    
    
    ## Calculate prediction quantiles and wrangle into a data frame
  quantiles <- round((quantile(2^predictions[,'upr']-2^predictions[,'lwr'],
                               qSD, na.rm = TRUE))/2,3) %>%
    as.list() %>% data.frame() %>%
    rename("q0.5" = "X50.", "q0.683" = "X68.27.", "q0.954" = "X99.73.")               
  
      ## Calculate coefficients of variance and wrangle into a data frame
  cv_quantiles <- round((quantile((2^predictions[,'upr']-2^predictions[,'lwr'])/
                                    (2^predictions[,'fit']),qSD, na.rm = TRUE))/2,3) %>%
    as.list() %>% data.frame() %>%
    rename("cv0.5" = "X50.", "cv0.683" = "X68.27.", "cv0.954" = "X99.73.")

    ## Combine quantiles and cv_quantiles, add a column for amino acids and return
  quants <- bind_cols(quantiles, cv_quantiles) %>% 
    mutate(amino_acid = aa)
  
  return(quants)  

}

 ## Calculate quantiles for each amino acid and gather into a data frame
quants <- do.call(rbind, lapply(modlist2, calc_quants))

 ## Join all stats for each model
model_stats <- left_join(res, quants, by = "amino_acid")

 ## Export stats to csv
write.csv(file = "Nps predictionQuantiles.csv", model_stats)

## 5.3 Plotting IEx A/I vs RP DL with models and uncertainties -------------------------------------

pred_plot <- function(aa, result = "print"){
  
    ## Predict DL values based on amino acid model
  pr <- predict(nps_models[[aa]], newdata = predData, interval = "prediction")   
  
    ## Collect DL and AI data and transform back to real values
  bu <- nps_log_bu %>% 
  ungroup() %>%
  mutate(rp_dl = 2^!!sym(paste0(aa, "_mean")), iex_ai = 2^logai_mean) %>%
  select(rp_dl, iex_ai)
  
    ## Create  polygon vector from prediction uncertainty ranges
  poly <- data.frame(x = c(2^predData$logai_mean,
                             rev(2^predData$logai_mean)), 
                     y = c(as.vector(2^pr[,'lwr']),
                             rev(as.vector(2^pr[,'upr']))))
  
    ## Create line vector for model
  line <- data.frame(x = c(2^predData$logai_mean), y = 2^pr[,'fit'])
 
    ## Set up plot using DL and AI values, and transformed poly and line
  p <- ggplot(data = bu, aes(x = iex_ai, y = rp_dl)) +
   geom_polygon(aes(x = x, y = y), data = poly, inherit.aes = FALSE,
                fill = palettes$five[[1]], alpha = 0.3) + 
   geom_point() +
   geom_line(aes(x = x, y = y), data = line, inherit.aes = FALSE)
    
    ## Prettify
  p2 <- quick_theme(p) + 
    labs(x = "Ion Exchange A/I", y = paste("Reverse Phase", aa, "D/L"))
  
      ## Choose whether to print or save according to result
  choose_print(q = p2, p_s = result,        
               name = paste0("AI to DL Pred Uncertainty -", aa, ".png"),
               w = 5, h = 5, res = 150)

} 

  ## Plot model over A/I vs D/L for each amino acid
pred_plot("Asx", "print")
pred_plot("Glx", "save")
pred_plot("Val", "save")
pred_plot("Ala", "save")
pred_plot("Ile", "save")
  
 ## Plot all amino acids in one file
p <- lapply(modlist2, pred_plot)
p2 <- marrangeGrob(p, nrow = 3, ncol = 2)
ggsave(filename = "AI to DL Pred Uncertainty all AAs.png", plot = p2,
       width = 6, height = 7.5, dpi = 150)


## 5.4 Generate "pooled" models using data set from Whitacre 2017 ----------------------------------

## Load original data set - see supp info of Whitacre et al. 2017
dataToUse <- read.csv(paste0("D:/Lucy Wheeler CV/AAR Data/N pachyderma/R/Whitacre 2017/",
                             "2014AI/data/Copy of Appendix_March_9_20162.csv"))
dataToUse <- dataToUse[!is.na(dataToUse[,'IE.AI.Avg']),] ## Remove instances of NA

  ## log the D/L
logai_mean <- log2(dataToUse[,'IE.AI.Avg'])
Asx <- log2(dataToUse[,'DL.Asp'])
Glx <- log2(dataToUse[,'DL.Glu'])
Ala <- log2(dataToUse[,'DL.Ala'])
Val <- log2(dataToUse[,'DL.Val'])
Ile <- log2(dataToUse[,'DL.Ile'])                                                
dataToUse <- cbind(dataToUse, logai_mean, Asx, Glx, Ala, Val, Ile)

  ## Tidy up
rm(logai_mean, Asx, Glx, Ala, Val, Ile)

  ## Create list of pooled models for each amino acid and rename 
pooled_models <- lapply(modlist2, function(x){
    lm(reformulate("logai_mean", x), data = dataToUse)
                })
names(pooled_models) <- modlist2

 ## Create D/L prediction intervals for each amino acid model, 
  # using nps data frame as the "new" data set, and rename
pr_pooled <- lapply(modlist2, function(x){
  predict(pooled_models[[x]], newdata = nps_log_bu, interval = "prediction") %>%
  data.frame() %>%
  mutate(logai_mean = nps_log_bu$logai_mean,
         measured_dl = nps_log_bu[[paste0(x, "_mean")]])
})
names(pr_pooled) <- modlist2

  ## Convert list into data frame and unlog, convert amino acid to factor and make new
   # variable containing success/failure to predict measured values
pr_pooled <- bind_rows(pr_pooled, .id = "amino_acid") %>%
  mutate(fit = 2^fit,
         lwr = 2^lwr,
         upr = 2^upr,
         logai_mean = 2^logai_mean,
         measured_dl = 2^measured_dl,
         amino_acid = fct_inorder(as.factor(amino_acid)),
         predict = case_when((measured_dl <= upr & measured_dl >= lwr) ~ "Yes",
                             (measured_dl >= upr | measured_dl <= lwr) ~ "No"))

  ## Plot predicted against measured values for pooled model
p <- ggplot(data = pr_pooled, aes(x = measured_dl, y = fit)) + 
      geom_errorbar(aes(ymin = lwr, ymax = upr), colour = palettes$five[[3]]) +
      geom_point() +
      facet_wrap(amino_acid ~ ., ncol = 2, scales = "free")

p2 <- quick_theme(p) +
         labs(x = "Measured RP D/L", y = "D/L predicted from IEx A/I")

p2

  ## Save to file
ggsave("Pooled model fit Nps data.png", 
       plot = p2, width = 5, height = 7.5, dpi = 150)


## Calculate % success rate for each amino acid
successes <- sapply(modlist2, function(aa){
  x <- pr_pooled %>% 
    filter(amino_acid == aa) %>% 
    group_by(predict)

  y <- tally(x)

  z <- round((y$n[[2]]/(y$n[[1]]+y$n[[2]])*100),2)
  
  return(z)
})

successes <- data.frame(success_rate = unname(successes)) %>%
  mutate(amino_acid = unlist(modlist2))

 ## Use calc_quants to calculate prediction quantiles for pooled model using nps data
  # as new data for prediction
  # prerequisite: calc_quants()
pooled_quants <- do.call(rbind, lapply(list("Asx", "Glx", "Ala", "Val", "Ile"), 
                                     calc_quants, mod = pooled_models, data = nps_log_bu))


# Collect summary statistics for each model
pooled_stats <- do.call(rbind,            ## rbind combines the lapply list into a matrix
    lapply(pooled_models, function(x) { ## Collect these bits of information from each model
      coefs <- coef(summary(x))
      c( slope = coefs["logai_mean", "Estimate"],          ## Collect slope
         slope_se = coefs["logai_mean","Std. Error"],      ## Collect +/- 1SD of slope
         intercept = coefs["(Intercept)", "Estimate"],     ## Collect intercept
         intercept_se = coefs["(Intercept)","Std. Error"], ## Collect +/1 1SD of intercept
         r2 = round(summary(x)$adj.r.squared, 4),          ## Collect R^2
         aic = round(AICc(x),2),                           ## Calculate AICc  
         k = AICc(x, return.K=TRUE)                        ## Calculate k
      )
    })
  )

pooled_stats <- data.frame(pooled_stats) %>%
    mutate(amino_acid = unlist(modlist2))

 ## Join success rate, quants and stats
pooled_results <- left_join(pooled_quants, successes, by = "amino_acid") %>%
  left_join(pooled_stats, by = "amino_acid")

 ## Export stats to csv
write.csv(file = "Pooled model predictionQuantiles.csv", pooled_results)


# 5.5 Plot pooled model and Nps model side by side -------------------------------------------------

  ## Make a vector of the shape of the prediction uncertainty envelope to use in 
   # geom_polygon()
poly_wrangle <- function(aa = "Asx", mod = "Nps"){
  
    ## Choose which set of models to use based on the argument mod
  if(mod == "Nps"){
    models <- nps_models
    pred <- predData
  }else{
    models <- pooled_models
    pred <- arrange(nps_log_bu, logai_mean) 
  }
  
    ## Predict DL values based on amino acid model
  pr <- predict(models[[aa]], newdata = pred, interval = "prediction")  
    ## Create  polygon vector from prediction uncertainty ranges
  
  poly <- data.frame(x = c(2^pred$logai_mean,
                             rev(2^pred$logai_mean)), 
                     y = c(as.vector(2^pr[,'lwr']),
                             rev(as.vector(2^pr[,'upr'])))) %>%
    mutate(amino_acid = aa,
           model = mod)
  return(poly)
}

 ## Use poly_wrangle to compile the polygon coordinates for each model
mod_polys <- rbind(do.call(rbind, lapply(modlist2, poly_wrangle)), 
                   do.call(rbind, lapply(modlist2, poly_wrangle, mod = "Pooled"))) %>%  
  mutate(amino_acid = fct_inorder(amino_acid))


  ## Make a vector for the model line to use in geom_line()
line_wrangle <- function(aa = "Asx", mod = "Nps"){
  
    ## Choose which set of models to use based on the argument mod
  if(mod == "Nps"){
    models <- nps_models
    pred <- predData
  }else{
    models <- pooled_models
    pred <- arrange(nps_log_bu, logai_mean)
  }
  
      ## Predict DL values based on amino acid model
    pr <- predict(models[[aa]], newdata = pred, interval = "prediction")  
      ## Create line vector for model
  line <- data.frame(x = c(2^pred$logai_mean), y = 2^pr[,'fit']) %>%
    mutate(amino_acid = aa,
           model = mod)
return(line)
}

 ## Use line_wrangle to compile the line coordinates for each model
mod_lines <- rbind(do.call(rbind, lapply(modlist2, line_wrangle)),
                   do.call(rbind, lapply(modlist2, line_wrangle, mod = "Pooled"))) %>%
  mutate(amino_acid = fct_inorder(amino_acid))

 ## Make data frame for mod points to use in geom_point()
points_wrangle <- function(aa = "Asx", mod = "Nps"){
  points <- nps_log_bu %>% 
  ungroup() %>%
  mutate(rp_dl = 2^!!sym(paste0(aa, "_mean")), iex_ai = 2^logai_mean,
         amino_acid = aa, mod = mod) %>%
  select(rp_dl, iex_ai, amino_acid, mod, b_u)
  
}

  ## Use points_wrangle to compile the point coordinates for each model
mod_points <- rbind(do.call(rbind, lapply(modlist2, points_wrangle)),
                   do.call(rbind, lapply(modlist2, points_wrangle, mod = "Pooled"))) %>%
  mutate(amino_acid = fct_inorder(amino_acid))


 ## Plot raw data (IEC A/I vs RP D/L), model lines and prediction uncertainty polygons
  # for each amino acid and pooled or Nps-specific model
p <- ggplot() +
   geom_polygon(aes(x = x, y = y), data = mod_polys, inherit.aes = FALSE,
                fill = "#bac6e1") +
   geom_line(aes(x = x, y = y), data = mod_lines, inherit.aes = FALSE) +
   geom_point(aes(x = iex_ai, y = rp_dl, colour = b_u), 
              data = mod_points, inherit.aes = FALSE, size = 0.5) +
  facet_grid(amino_acid ~ model)

  ## Some extra formatting
p2 <- quick_theme(p) +
        scale_colour_manual(values = palettes$bl) +
        labs(x = "IEC Ile A/I", y = "RP-HPLC D/L", colour = NULL) +
       theme(legend.box.spacing = unit(0, "cm"),
           legend.margin = margin(0,0,0,0, unit = "mm"))


  ## Save to file
ggsave(filename = paste0(graph_loc, 
                         "AI to DL Pred Uncertainty Nps and Pooled Models.eps"), 
       plot = p2, width = 90, height = 150, device = "eps", units = "mm")


## 6.0 Map of region -------------------------------------------------------------------------------

  ## Packages to collect map data
library(marmap)
library(rnaturalearth)
library(rnaturalearthdata)

 ## Package to plot national boundaries  
library(sf)


  ## Collect bathymetry data from NOAA
nps_map <- getNOAA.bathy(lon1 = -7, lon2 = 12, lat1 = 57, lat2 = 66, resolution = 4)
  ## Convert bathymetry data to dataframe 
nps_map <- fortify(nps_map)                                                             
nps_map <- nps_map %>% mutate(z = -z)

  ## Build data frame for map labels (core location, country/sea labels, axis labels)
labels <- data.frame(x = c(4,8,1.5,2,-5.7,-5.7,-5.7,-5,0,5,10), 
                     y = c(64.8,61,64,58,70,65,60,57.5,57.5,57.5,57.5), 
                     z = c(0,0,0,0,0,0,0,0,0,0,0), 
                     label = c("MD99-2288,\nMD99-2289", "Norway", "Norwegian\nSea","North\nSea", 
                               "70N", "65N", "60N", "5W", "0", "5E", "10E"))


  ## Build data frame for isobath labels
isobaths <- data.frame(x = c(-1.94, -0.8, -0.15, 1.83, 2.79),
                       y = c(64.9, 63.5, 62.4, 62.4, 61.0), 
                       z = c(3000, 2000, 1000, 500, 250))

  ## Collect national borders
pays <- rnaturalearth::ne_countries(
  country = c("Norway", "United Kingdom", "Ireland", "Denmark", "Sweden"),
  scale = "medium", returnclass = "sf"
)


pl <- ggplot(data = pays) +
  stat_contour(data = nps_map, aes(x = x, y = y, z = z, colour = ..level..), size = 0.1,
               breaks = c(0, 250, 500, 1000, 2000, 3000)) +
  geom_sf(fill = "grey60", colour = "gray20", size = 0.1) +
  geom_label(data = isobaths, aes(x = x, y = y, label = z), size = 2, colour = "gray40",
             label.padding = unit(0.1, "lines"), label.size = unit(0, "mm"))  +
  geom_point(data = data.frame(x = 04.1257, y = 64.3939, z = 0), aes(x = x, y = y), size = 1) + 
  geom_label(data = labels, aes(x = x, y = y, label = label), size = 2,
             hjust = 0.5, label.padding = unit(0.1, "lines"), 
             label.size = unit(1, "mm")) +
  scale_x_continuous(expand = c(0,0), breaks = c(-5, 0, 5, 10), limits = c(-7, 12)) +        
  scale_y_continuous(expand = c(0,0), breaks = c(60, 65), limits = c(57, 66))

  
  ## Formatting
p2 <- quick_theme(pl, key_pos = "none") + 
  labs(y = NULL, x = NULL) +
  scale_colour_gradient(low = "gray30", high = "gray50") +
  theme(axis.ticks.length = unit(-0.25, "cm"), 
        axis.text.x = element_blank(), 
        axis.text.y = element_blank(),
        plot.margin = margin(t = 2, r = 2, b = 4, l = 4, unit = "mm"))

  ## Save to file
ggsave(filename = paste0(graph_loc, "MD99-2288 89 Map 2.eps"), plot = p2,      
       width = 90, height = 90, device = "eps", units = "mm")